==> chatgpt_plugin-1.0.0.tar.gz: chatgpt_plugin/src/Form/ChatGPTForm.php <==
<?php

namespace Drupal\chatgpt\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Serialization\Json;

/**
 * Function to create the ChatGPT Search popup.
 */
class ChatGPTForm extends FormBase {

  /**
   * The default http client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('http_client')
    );
  }

  /**
   * Constructor of the class.
   *
   * @param \GuzzleHttp\ClientInterface $http_client
   *   An http client.
   */
  public function __construct(ClientInterface $http_client) {
    $this->httpClient = $http_client;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'chatgpt_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['chatgpt_search'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Search content in ChatGPT'),
      '#required' => TRUE,
    ];

    $form['chatgpt_submit'] = [
      '#type' => 'button',
      '#value' => 'Search',
      '#ajax' => [
        'callback' => '::chatgptSearchResult',
        'effect' => 'fade',
        'event' => 'click',
        'progress' => [
          'type' => 'throbber',
          'message' => $this->t('Getting Result from OpenAI ChatGPT...'),
        ],
      ],
    ];

    $form['chatgpt_result'] = [
      '#type' => 'markup',
      '#title' => $this->t('ChatGPT Result'),
      '#markup' => '<div id="chatgpt-result"></div>',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * Ajax callback function to call the ChatGPT API.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function chatgptSearchResult(array &$form, FormStateInterface $form_state) {
    $ajax_response = new AjaxResponse();
    $config = $this->config('chatgpt.adminsettings');
    $prompt_text = $form_state->getValue('chatgpt_search');
    $url = $config->get('chatgpt_endpoint');
    $model = $config->get('chatgpt_model');
    $access_token = $config->get('chatgpt_token');
    $temperature = (int) $config->get('chatgpt_temperature');
    $max_tokens = (int) $config->get('chatgpt_max_token');

    $payload = [
      "model" => $model,
      "prompt" => $prompt_text,
      "temperature" => $temperature,
      "max_tokens" => $max_tokens,
    ];
    $header = [
      'Content-Type' => 'application/json',
      'Authorization' => 'Bearer ' . $access_token,
    ];
    $options = [
      'headers' => $header,
      'json' => $payload,
    ];

    // Calling ChatGPT completion API.
    try {
      $response = $this->httpClient->request('POST', $url, $options);
      $result = $response->getBody()->getContents();
      $decoded_data = Json::decode($result);
    }
    catch (GuzzleException $exception) {
      // Error handling for ChatGPT API call.
      $error_msg = $exception->getMessage();
      $ajax_response->addCommand(new HtmlCommand('#chatgpt-result', $error_msg));
      return $ajax_response;
    }

    // Processing success response data.
    $text = $decoded_data['choices'][0]['text'];
    $ajax_response->addCommand(new HtmlCommand('#chatgpt-result', $text));
    return $ajax_response;
  }

}

==> chatgpt_plugin-1.0.1.tar.gz: chatgpt_plugin/src/Form/ChatGPTForm.php <==
<?php

namespace Drupal\chatgpt_plugin\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Serialization\Json;

/**
 * Function to create the ChatGPT Search popup.
 */
class ChatGPTForm extends FormBase {

  /**
   * The default http client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('http_client')
    );
  }

  /**
   * Constructor of the class.
   *
   * @param \GuzzleHttp\ClientInterface $http_client
   *   An http client.
   */
  public function __construct(ClientInterface $http_client) {
    $this->httpClient = $http_client;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'chatgpt_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['chatgpt_search'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Search content in ChatGPT'),
    ];

    $form['chatgpt_submit'] = [
      '#type' => 'button',
      '#value' => 'Search',
      '#ajax' => [
        'callback' => '::chatgptSearchResult',
        'effect' => 'fade',
        'event' => 'click',
        'progress' => [
          'type' => 'throbber',
          'message' => $this->t('Getting Result from OpenAI ChatGPT...'),
        ],
      ],
    ];

    $form['chatgpt_result'] = [
      '#type' => 'markup',
      '#title' => $this->t('ChatGPT Result'),
      '#markup' => '<div id="chatgpt-result"></div>',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * Ajax callback function to call the ChatGPT API.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function chatgptSearchResult(array &$form, FormStateInterface $form_state) {
    $ajax_response = new AjaxResponse();
    $config = $this->config('chatgpt_plugin.adminsettings');
    $prompt_text = $form_state->getValue('chatgpt_search');
    $url = $config->get('chatgpt_endpoint');
    $model = $config->get('chatgpt_model');
    $access_token = $config->get('chatgpt_token');
    $temperature = (int) $config->get('chatgpt_temperature');
    $max_tokens = (int) $config->get('chatgpt_max_token');

    $payload = [
      "model" => $model,
      "prompt" => $prompt_text,
      "temperature" => $temperature,
      "max_tokens" => $max_tokens,
    ];
    $header = [
      'Content-Type' => 'application/json',
      'Authorization' => 'Bearer ' . $access_token,
    ];
    $options = [
      'headers' => $header,
      'json' => $payload,
    ];

    // Calling ChatGPT completion API.
    try {
      $response = $this->httpClient->request('POST', $url, $options);
      $result = $response->getBody()->getContents();
      $decoded_data = Json::decode($result);
    }
    catch (GuzzleException $exception) {
      // Error handling for ChatGPT API call.
      $error_msg = $exception->getMessage();
      $ajax_response->addCommand(new HtmlCommand('#chatgpt-result', $error_msg));
      return $ajax_response;
    }

    // Processing success response data.
    $text = $decoded_data['choices'][0]['text'];
    $ajax_response->addCommand(new HtmlCommand('#chatgpt-result', $text));
    return $ajax_response;
  }

}
